Documentation
¶
Index ¶
Constants ¶
const ( LoopSetFd = C.LOOP_SET_FD LoopCtlGetFree = C.LOOP_CTL_GET_FREE LoopGetStatus64 = C.LOOP_GET_STATUS64 LoopSetStatus64 = C.LOOP_SET_STATUS64 LoopClrFd = C.LOOP_CLR_FD LoopSetCapacity = C.LOOP_SET_CAPACITY )
IOCTL consts.
const ( LoFlagsAutoClear = C.LO_FLAGS_AUTOCLEAR LoFlagsReadOnly = C.LO_FLAGS_READ_ONLY LoFlagsPartScan = C.LO_FLAGS_PARTSCAN LoKeySize = C.LO_KEY_SIZE LoNameSize = C.LO_NAME_SIZE )
LOOP consts.
Variables ¶
var ( // ErrAttachLoopbackDevice failed to attach the loopback device ErrAttachLoopbackDevice = errors.New("loopback mounting failed") )
Functions ¶
func AttachLoopDevice ¶
AttachLoopDevice attaches the given sparse file to the next available loopback device. It returns an opened *os.File. The loopback file is set to autoclear after the returned file handle is closed.
Example
```
fh, err := os.OpenFile(filename, os.O_RDWR|os.O_CREATE, 0600)
if err != nil {
return err
}
if err := fh.Truncate(size); err != nil {
return err
}
if err := fh.Close(); err != nil {
return err
}
lHandle, err := loop.AttachLoopDevice(filename)
if err != nil {
return err
}
[...]
```
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.